@@ -2,7 +2,7 @@ lgm <- function(data,  locations, covariates=NULL, formula=NULL,
 		shape=1, fixShape=TRUE,
 		aniso=FALSE, boxcox=1, fixBoxcox=TRUE,
 		nugget = 0, fixNugget = FALSE,
-		expPred=FALSE, nuggetInPrediction=TRUE){
+		expPred=FALSE, nuggetInPrediction=TRUE,...){
 	
 	
 # the formula
@@ -15,10 +15,14 @@ lgm <- function(data,  locations, covariates=NULL, formula=NULL,
 		formula = names(data)[formula]
 	if(class(formula)!= "formula") {
 		if(length(covariates)) {
-			if(!length(names(covariates)))
-				names(covariates) = paste("c", 1:length(covariates),sep="")			
-			names(covariates) = gsub("[[:punct:]]|[[:space:]]","_", names(covariates))
-			
+			if(!length(names(covariates))) {
+				names(covariates) = 
+						paste("c", 1:length(covariates),sep="")			
+			}
+			names(covariates) = 
+					gsub("[[:punct:]]|[[:space:]]",
+							"_", names(covariates))
+
 			formula = as.formula(
 					paste(formula, "~ ",
 							paste(names(covariates),collapse="+")
@@ -81,10 +85,20 @@ lgm <- function(data,  locations, covariates=NULL, formula=NULL,
 	if(! all(notInData %in% names(covariates)))
 		warning("some terms in the model are missing from both the data and the covariates")
 
+	dots <- list(...)  
+	if(any(names(dots)=='param')) {
+		param=dots$param	
+	} else {
+		param=c()
+	}
 	
-	param = c(range=sd(coordinates(data)[,1]),
-				shape=shape, nugget=nugget,boxcox=boxcox
-				)
+	param['shape']=shape
+	param['nugget']=nugget
+	param['boxcox']=boxcox
+
+	if(!any(names(param)=='range'))
+		param['range']=sd(coordinates(data)[,1])
+					
 	paramToEstimate	= c("range", "shape","nugget","boxcox")[
 			!c(FALSE,fixShape,fixNugget,fixBoxcox)]		
 	if(aniso) {
@@ -100,21 +114,30 @@ lgm <- function(data,  locations, covariates=NULL, formula=NULL,
 	
 # call likfit
 	
+	dots$param = param
+	dots$trend=formula
+	dots$data=data
+	dots$paramToEstimate=paramToEstimate
  	
-	likRes = likfitLgm(data=data, trend=formula,
-			param=param, paramToEstimate=paramToEstimate
-	)
+
+	
+	likRes = do.call(likfitLgm, dots)
+
+
+	
+
 	
 # call krige	
-	
- 
 	krigeRes =  krige(data=data,trend=formula,
 			param=likRes$param, locations=locations,
 			covariates=covariates, expPred=expPred,
 			nuggetInPrediction=nuggetInPrediction
 			)
 	 
-	res = c(predict=krigeRes, likRes)
+	res = c(predict=krigeRes, likRes, list(data=data))
+	
+	# add confidence intervals for covariance parameters
+	res$summary = informationLgm(res)$summary
 	
 	
 	for(Dvar in names(covariates)) {
@@ -129,6 +152,10 @@ lgm <- function(data,  locations, covariates=NULL, formula=NULL,
 			}
 		}
 	}
+	
+	
+
+	
 	return(res)
 }
 
