@@ -30,8 +30,8 @@ bob(swissFit)
 
 # specify formula using name of list element
 
-swissFitAgain = lgm(data=swissRain, formula=rain~ elev,
-		locations=80, covariates=list(elev=swissAltitude),
+swissFitAgain = lgm(data=swissRain, formula=rain~ elev+land,
+		locations=80, covariates=list(elev=swissAltitude,land=swissLandType),
 		shape=1,  fixShape=TRUE, 
 		boxcox=0.5, fixBoxcox=TRUE, 
 		aniso=TRUE)	
@@ -50,7 +50,7 @@ bob(swissFitAgain)
 
 
 swissFitAgain = lgm(data=swissRain, formula="rain",
-		locations=80, covariates=list(elev=swissAltitude),
+		locations=80, covariates=list(elev=swissAltitude,land=swissLandType),
 		shape=1,  fixShape=TRUE, 
 		boxcox=0.5, fixBoxcox=TRUE, 
 		aniso=TRUE)	
@@ -84,6 +84,13 @@ names(covariates) = c("cov1","cov2")
 
 Npoints = 40
 myPoints = SpatialPoints(cbind(runif(Npoints,0,10), runif(Npoints,0,10)))	
+# check for points too close together
+thedist = spDists(myPoints)
+thedist[lower.tri(thedist,diag=TRUE)]=NA
+thedist = apply(thedist<0.2,2, any,na.rm=TRUE)
+myPoints = myPoints[!thedist]
+
+
 myPoints = SpatialPointsDataFrame(myPoints, 
 		data=as.data.frame(extract(covariates, myPoints)))
 library("RandomFields")
@@ -128,6 +135,7 @@ dev.off()
 fitMLE =  lgm(myPoints, locations=10, formula=y~ cov1 + cov2, 
 		shape=1, fixShape=TRUE)
 
+
 c(fitMLE$summary["range","estimate"], fitLikfit$summary["range","estimate"])
 bob(fitMLE)
 
